==> devextreme-23.1.13.tgz: package/cjs/renovation/ui/pager/utils/get_element_width.js <==
/**
 * DevExtreme (cjs/renovation/ui/pager/utils/get_element_width.js)
 * Version: 23.1.13
 * Build date: Mon Oct 28 2024
 *
 * Copyright (c) 2012 - 2024 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.getElementContentWidth = getElementContentWidth;
exports.getElementMinWidth = getElementMinWidth;
exports.getElementStyle = getElementStyle;
exports.getElementWidth = getElementWidth;
var _get_computed_style = _interopRequireDefault(require("../../../utils/get_computed_style"));
var _type_conversion = require("../../../utils/type_conversion");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function getElementStyle(name, element) {
    var _getElementComputedSt;
    var computedStyle = null !== (_getElementComputedSt = (0, _get_computed_style.default)(element)) && void 0 !== _getElementComputedSt ? _getElementComputedSt : {};
    return (0, _type_conversion.toNumber)(computedStyle[name])
}

function getElementContentWidth(element) {
    var padding = getElementStyle("paddingLeft", element) + getElementStyle("paddingRight", element);
    var width = getElementStyle("width", element);
    return width - padding
}

function getElementWidth(element) {
    var margin = getElementStyle("marginLeft", element) + getElementStyle("marginRight", element);
    var width = getElementStyle("width", element);
    return margin + width
}

function getElementMinWidth(element) {
    return getElementStyle("minWidth", element)
}

==> devextreme-23.2.3.tgz: package/cjs/renovation/ui/pager/utils/get_element_width.js <==
/**
 * DevExtreme (cjs/renovation/ui/pager/utils/get_element_width.js)
 * Version: 23.2.3
 * Build date: Tue Nov 28 2023
 *
 * Copyright (c) 2012 - 2023 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.getElementContentWidth = getElementContentWidth;
exports.getElementMinWidth = getElementMinWidth;
exports.getElementStyle = getElementStyle;
exports.getElementWidth = getElementWidth;
var _get_computed_style = _interopRequireDefault(require("../../../utils/get_computed_style"));
var _type_conversion = require("../../../utils/type_conversion");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function getElementStyle(name, element) {
    var _getElementComputedSt;
    const computedStyle = null !== (_getElementComputedSt = (0, _get_computed_style.default)(element)) && void 0 !== _getElementComputedSt ? _getElementComputedSt : {};
    return (0, _type_conversion.toNumber)(computedStyle[name])
}

function getElementContentWidth(element) {
    const padding = getElementStyle("paddingLeft", element) + getElementStyle("paddingRight", element);
    const width = getElementStyle("width", element);
    return width - padding
}

function getElementWidth(element) {
    const margin = getElementStyle("marginLeft", element) + getElementStyle("marginRight", element);
    const width = getElementStyle("width", element);
    return margin + width
}

function getElementMinWidth(element) {
    return getElementStyle("minWidth", element)
}
